@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 # Copyright (C) 2008 Truelite Srl <info@truelite.it>
 # Author: Filippo Giunchedi <filippo@truelite.it>
@@ -15,7 +15,10 @@
 from pysnmp.carrier.twisted.dispatch import TwistedDispatcher
 from pysnmp.carrier.base import AbstractTransport
 
+
 class AbstractTwistedTransport(AbstractTransport):
     protoTransportDispatcher = TwistedDispatcher
-    def __init__(self):
+
+    def __init__(self, sock=None, sockMap=None):
         self._writeQ = []
+        AbstractTransport.__init__(self)
