@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 import logging
 from pyasn1.compat.octets import octs2ints
@@ -34,7 +34,8 @@ flagMap = {'io': flagIO,
            'app': flagApp,
            'all': flagAll}
 
-class Printer:
+
+class Printer(object):
     def __init__(self, logger=None, handler=None, formatter=None):
         if logger is None:
             logger = logging.getLogger('pysnmp')
@@ -54,6 +55,7 @@ class Printer:
     def __str__(self):
         return '<python built-in logging>'
 
+
 if hasattr(logging, 'NullHandler'):
     NullHandler = logging.NullHandler
 else:
@@ -62,8 +64,10 @@ else:
         def emit(self, record):
             pass
 
-class Debug:
+
+class Debug(object):
     defaultPrinter = None
+
     def __init__(self, *flags, **options):
         self._flags = flagNone
         if options.get('printer') is not None:
@@ -106,13 +110,17 @@ class Debug:
     def __rand__(self, flag):
         return flag & self._flags
 
+
 # This will yield false from bitwise and with a flag, and save
 # on unnecessary calls
 logger = 0
 
+
 def setLogger(l):
     global logger
     logger = l
 
+
 def hexdump(octets):
-    return ' '.join(['%s%.2X' % (n%16 == 0 and ('\n%.5d: ' % n) or '', x) for n, x in zip(range(len(octets)), octs2ints(octets))])
+    return ' '.join(
+        ['%s%.2X' % (n % 16 == 0 and ('\n%.5d: ' % n) or '', x) for n, x in zip(range(len(octets)), octs2ints(octets))])
