@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 # All code in this file belongs to obsolete, compatibility wrappers.
 # Never use interfaces below for new applications!
@@ -18,7 +18,8 @@ __all__ = ['AsynCommandGenerator', 'CommandGenerator', 'MibVariable']
 
 MibVariable = ObjectIdentity
 
-class AsynCommandGenerator:
+
+class AsynCommandGenerator(object):
     _null = univ.Null('')
 
     vbProcessor = CommandGeneratorVarBinds()
@@ -26,7 +27,7 @@ class AsynCommandGenerator:
 
     def __init__(self, snmpEngine=None):
         if snmpEngine is None:
-            self.snmpEngine = snmpEngine = SnmpEngine()
+            self.snmpEngine = SnmpEngine()
         else:
             self.snmpEngine = snmpEngine
 
@@ -95,7 +96,6 @@ class AsynCommandGenerator:
         if contextName is null and authData.contextName:
             contextName = authData.contextName
 
-
         return setCmd(
             self.snmpEngine, authData, transportTarget,
             ContextData(contextEngineId, contextName), *varBinds,
@@ -159,8 +159,10 @@ class AsynCommandGenerator:
 
     asyncBulkCmd = bulkCmd
 
-class CommandGenerator:
+
+class CommandGenerator(object):
     _null = univ.Null('')
+
     def __init__(self, snmpEngine=None, asynCmdGen=None):
         # compatibility attributes
         self.snmpEngine = snmpEngine or SnmpEngine()
@@ -171,14 +173,14 @@ class CommandGenerator:
         if 'lookupValues' not in kwargs:
             kwargs['lookupValues'] = False
         errorIndication, errorStatus, errorIndex, varBinds = None, 0, 0, []
-        for errorIndication, \
-                errorStatus, errorIndex, \
-                varBinds \
-                in sync.getCmd(self.snmpEngine, authData, transportTarget,
-                               ContextData(kwargs.get('contextEngineId'),
-                                           kwargs.get('contextName', null)),
-                               *[(x, self._null) for x in varNames],
-                               **kwargs):
+        for (errorIndication,
+             errorStatus,
+             errorIndex,
+             varBinds) in sync.getCmd(self.snmpEngine, authData, transportTarget,
+                                      ContextData(kwargs.get('contextEngineId'),
+                                                  kwargs.get('contextName', null)),
+                                      *[(x, self._null) for x in varNames],
+                                      **kwargs):
             break
         return errorIndication, errorStatus, errorIndex, varBinds
 
@@ -188,14 +190,14 @@ class CommandGenerator:
         if 'lookupValues' not in kwargs:
             kwargs['lookupValues'] = False
         errorIndication, errorStatus, errorIndex, rspVarBinds = None, 0, 0, []
-        for errorIndication, \
-                errorStatus, errorIndex, \
-                rspVarBinds \
-                in sync.setCmd(self.snmpEngine, authData, transportTarget,
-                               ContextData(kwargs.get('contextEngineId'),
-                                           kwargs.get('contextName', null)),
-                               *varBinds,
-                               **kwargs):
+        for (errorIndication,
+             errorStatus,
+             errorIndex,
+             rspVarBinds) in sync.setCmd(self.snmpEngine, authData, transportTarget,
+                                         ContextData(kwargs.get('contextEngineId'),
+                                                     kwargs.get('contextName', null)),
+                                         *varBinds,
+                                         **kwargs):
             break
 
         return errorIndication, errorStatus, errorIndex, rspVarBinds
@@ -209,14 +211,14 @@ class CommandGenerator:
             kwargs['lexicographicMode'] = False
         errorIndication, errorStatus, errorIndex = None, 0, 0
         varBindTable = []
-        for errorIndication, \
-                errorStatus, errorIndex, \
-                varBinds \
-                in sync.nextCmd(self.snmpEngine, authData, transportTarget,
-                                ContextData(kwargs.get('contextEngineId'),
-                                            kwargs.get('contextName', null)),
-                                *[(x, self._null) for x in varNames],
-                                **kwargs):
+        for (errorIndication,
+             errorStatus,
+             errorIndex,
+             varBinds) in sync.nextCmd(self.snmpEngine, authData, transportTarget,
+                                       ContextData(kwargs.get('contextEngineId'),
+                                                   kwargs.get('contextName', null)),
+                                       *[(x, self._null) for x in varNames],
+                                       **kwargs):
             if errorIndication or errorStatus:
                 return errorIndication, errorStatus, errorIndex, varBinds
 
@@ -234,16 +236,16 @@ class CommandGenerator:
             kwargs['lexicographicMode'] = False
         errorIndication, errorStatus, errorIndex = None, 0, 0
         varBindTable = []
-        for errorIndication, \
-                errorStatus, errorIndex, \
-                varBinds \
-                in sync.bulkCmd(self.snmpEngine, authData,
-                                transportTarget,
-                                ContextData(kwargs.get('contextEngineId'),
-                                            kwargs.get('contextName', null)),
-                                nonRepeaters, maxRepetitions,
-                                *[(x, self._null) for x in varNames],
-                                **kwargs):
+        for (errorIndication,
+             errorStatus,
+             errorIndex,
+             varBinds) in sync.bulkCmd(self.snmpEngine, authData,
+                                       transportTarget,
+                                       ContextData(kwargs.get('contextEngineId'),
+                                                   kwargs.get('contextName', null)),
+                                       nonRepeaters, maxRepetitions,
+                                       *[(x, self._null) for x in varNames],
+                                       **kwargs):
             if errorIndication or errorStatus:
                 return errorIndication, errorStatus, errorIndex, varBinds
 
