@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 # Copyright (C) 2014, Zebra Technologies
 # Authors: Matt Hooks <me@matthooks.com>
@@ -38,6 +38,7 @@ from pysnmp.hlapi.lcd import *
 from pysnmp.hlapi.varbinds import *
 from pysnmp.hlapi.asyncio.transport import *
 from pysnmp.entity.rfc3413 import cmdgen
+
 try:
     import asyncio
 except ImportError:
@@ -50,6 +51,7 @@ lcd = CommandGeneratorLcdConfigurator()
 
 isEndOfMib = lambda x: not cmdgen.getNextVarBinds(x)[1]
 
+
 @asyncio.coroutine
 def getCmd(snmpEngine, authData, transportTarget, contextData,
            *varBinds, **options):
@@ -125,15 +127,22 @@ def getCmd(snmpEngine, authData, transportTarget, contextData,
     >>>
 
     """
+
     def __cbFun(snmpEngine, sendRequestHandle,
                 errorIndication, errorStatus, errorIndex,
                 varBinds, cbCtx):
         lookupMib, future = cbCtx
         if future.cancelled():
             return
-        future.set_result(
-            (errorIndication, errorStatus, errorIndex, vbProcessor.unmakeVarBinds(snmpEngine, varBinds, lookupMib))
-        )
+        try:
+            varBindsUnmade = vbProcessor.unmakeVarBinds(snmpEngine, varBinds,
+                                                        lookupMib)
+        except Exception as e:
+            future.set_exception(e)
+        else:
+            future.set_result(
+                (errorIndication, errorStatus, errorIndex, varBindsUnmade)
+            )
 
     addrName, paramsName = lcd.configure(snmpEngine, authData, transportTarget)
 
@@ -147,6 +156,7 @@ def getCmd(snmpEngine, authData, transportTarget, contextData,
     )
     return future
 
+
 @asyncio.coroutine
 def setCmd(snmpEngine, authData, transportTarget, contextData,
            *varBinds, **options):
@@ -222,15 +232,22 @@ def setCmd(snmpEngine, authData, transportTarget, contextData,
     >>>
 
     """
+
     def __cbFun(snmpEngine, sendRequestHandle,
                 errorIndication, errorStatus, errorIndex,
                 varBinds, cbCtx):
         lookupMib, future = cbCtx
         if future.cancelled():
             return
-        future.set_result(
-            (errorIndication, errorStatus, errorIndex, vbProcessor.unmakeVarBinds(snmpEngine, varBinds, lookupMib))
-        )
+        try:
+            varBindsUnmade = vbProcessor.unmakeVarBinds(snmpEngine, varBinds,
+                                                        lookupMib)
+        except Exception as e:
+            future.set_exception(e)
+        else:
+            future.set_result(
+                (errorIndication, errorStatus, errorIndex, varBindsUnmade)
+            )
 
     addrName, paramsName = lcd.configure(snmpEngine, authData, transportTarget)
 
@@ -244,6 +261,7 @@ def setCmd(snmpEngine, authData, transportTarget, contextData,
     )
     return future
 
+
 @asyncio.coroutine
 def nextCmd(snmpEngine, authData, transportTarget, contextData,
             *varBinds, **options):
@@ -323,15 +341,24 @@ def nextCmd(snmpEngine, authData, transportTarget, contextData,
     >>>
 
     """
+
     def __cbFun(snmpEngine, sendRequestHandle,
                 errorIndication, errorStatus, errorIndex,
                 varBindTable, cbCtx):
         lookupMib, future = cbCtx
         if future.cancelled():
             return
-        future.set_result(
-            (errorIndication, errorStatus, errorIndex, [vbProcessor.unmakeVarBinds(snmpEngine, varBindTableRow, lookupMib) for varBindTableRow in varBindTable])
-        )
+        try:
+            varBindsUnmade = [vbProcessor.unmakeVarBinds(snmpEngine,
+                                                         varBindTableRow,
+                                                         lookupMib)
+                              for varBindTableRow in varBindTable]
+        except Exception as e:
+            future.set_exception(e)
+        else:
+            future.set_result(
+                (errorIndication, errorStatus, errorIndex, varBindsUnmade)
+            )
 
     addrName, paramsName = lcd.configure(snmpEngine, authData, transportTarget)
 
@@ -345,6 +372,7 @@ def nextCmd(snmpEngine, authData, transportTarget, contextData,
     )
     return future
 
+
 @asyncio.coroutine
 def bulkCmd(snmpEngine, authData, transportTarget, contextData,
             nonRepeaters, maxRepetitions, *varBinds, **options):
@@ -399,13 +427,31 @@ def bulkCmd(snmpEngine, authData, transportTarget, contextData,
         True value indicates SNMP PDU error.
     errorIndex : int
         Non-zero value refers to `varBinds[errorIndex-1]`
-    varBinds : tuple
+    varBindTable : tuple
         A sequence of sequences (e.g. 2-D array) of
         :py:class:`~pysnmp.smi.rfc1902.ObjectType` class instances
-        representing a table of MIB variables returned in SNMP response.
-        Inner sequences represent table rows and ordered exactly the same
-        as `varBinds` in request. Response to GETNEXT always contain
-        a single row.
+        representing a table of MIB variables returned in SNMP response, with
+        up to ``maxRepetitions`` rows, i.e.
+        ``len(varBindTable) <= maxRepetitions``.
+
+        For ``0 <= i < len(varBindTable)`` and ``0 <= j < len(varBinds)``,
+        ``varBindTable[i][j]`` represents:
+
+        - For non-repeaters (``j < nonRepeaters``), the first lexicographic
+          successor of ``varBinds[j]``, regardless the value of ``i``, or an
+          :py:class:`~pysnmp.smi.rfc1902.ObjectType` instance with the
+          :py:obj:`~pysnmp.proto.rfc1905.endOfMibView` value if no such
+          successor exists;
+        - For repeaters (``j >= nonRepeaters``), the ``i``-th lexicographic
+          successor of ``varBinds[j]``, or an
+          :py:class:`~pysnmp.smi.rfc1902.ObjectType` instance with the
+          :py:obj:`~pysnmp.proto.rfc1905.endOfMibView` value if no such
+          successor exists.
+
+        See :rfc:`3416#section-4.2.3` for details on the underlying
+        ``GetBulkRequest-PDU`` and the associated ``GetResponse-PDU``, such as
+        specific conditions under which the server may truncate the response,
+        causing ``varBindTable`` to have less than ``maxRepetitions`` rows.
 
     Raises
     ------
@@ -420,7 +466,7 @@ def bulkCmd(snmpEngine, authData, transportTarget, contextData,
     >>>
     >>> @asyncio.coroutine
     ... def run():
-    ...     errorIndication, errorStatus, errorIndex, varBinds = yield from nextCmd(
+    ...     errorIndication, errorStatus, errorIndex, varBinds = yield from bulkCmd(
     ...         SnmpEngine(),
     ...         CommunityData('public'),
     ...         UdpTransportTarget(('demo.snmplabs.com', 161)),
@@ -431,19 +477,28 @@ def bulkCmd(snmpEngine, authData, transportTarget, contextData,
     ...     print(errorIndication, errorStatus, errorIndex, varBinds)
     >>>
     >>> asyncio.get_event_loop().run_until_complete(run())
-    (None, 0, 0, [[ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.1.0')), DisplayString('SunOS zeus.snmplabs.com 4.1.3_U1 1 sun4m')), ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.2.0')), ObjectIdentifier('1.3.6.1.4.1.424242.1.1')]])
+    (None, 0, 0, [[ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.1.0')), DisplayString('SunOS zeus.snmplabs.com 4.1.3_U1 1 sun4m'))], [ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.2.0')), ObjectIdentifier('1.3.6.1.4.1.424242.1.1'))]])
     >>>
 
     """
+
     def __cbFun(snmpEngine, sendRequestHandle,
                 errorIndication, errorStatus, errorIndex,
                 varBindTable, cbCtx):
         lookupMib, future = cbCtx
         if future.cancelled():
             return
-        future.set_result(
-            (errorIndication, errorStatus, errorIndex, [vbProcessor.unmakeVarBinds(snmpEngine, varBindTableRow, lookupMib) for varBindTableRow in varBindTable])
-        )
+        try:
+            varBindsUnmade = [vbProcessor.unmakeVarBinds(snmpEngine,
+                                                         varBindTableRow,
+                                                         lookupMib)
+                              for varBindTableRow in varBindTable]
+        except Exception as e:
+            future.set_exception(e)
+        else:
+            future.set_result(
+                (errorIndication, errorStatus, errorIndex, varBindsUnmade)
+            )
 
     addrName, paramsName = lcd.configure(snmpEngine, authData, transportTarget)
 
