@@ -1,12 +1,13 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 from pysnmp.proto import error
 
-class Cache:
+
+class Cache(object):
     def __init__(self):
         self.__cacheRepository = {}
 
@@ -26,7 +27,7 @@ class Cache:
         if index not in self.__cacheRepository:
             raise error.ProtocolError(
                 'Cache miss on update for %s' % kwargs
-                )
+            )
         self.__cacheRepository[index].update(kwargs)
 
     def expire(self, cbFun, cbCtx):
