@@ -1,14 +1,16 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 from pysnmp.proto.secmod import cache
 from pysnmp.proto import error
 
-class AbstractSecurityModel:
+
+class AbstractSecurityModel(object):
     securityModelID = None
+
     def __init__(self):
         self._cache = cache.Cache()
 
