@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 import time
 
@@ -11,7 +11,7 @@ MibScalarInstance, = mibBuilder.importSymbols('SNMPv2-SMI', 'MibScalarInstance')
 (snmpEngineID,
  snmpEngineBoots,
  snmpEngineTime,
- snmpEngineMaxMessageSize ) = mibBuilder.importSymbols(
+ snmpEngineMaxMessageSize) = mibBuilder.importSymbols(
     'SNMP-FRAMEWORK-MIB',
     'snmpEngineID',
     'snmpEngineBoots',
@@ -22,12 +22,13 @@ MibScalarInstance, = mibBuilder.importSymbols('SNMPv2-SMI', 'MibScalarInstance')
 __snmpEngineID = MibScalarInstance(snmpEngineID.name, (0,), snmpEngineID.syntax)
 __snmpEngineBoots = MibScalarInstance(snmpEngineBoots.name, (0,), snmpEngineBoots.syntax.clone(1))
 __snmpEngineTime = MibScalarInstance(snmpEngineTime.name, (0,), snmpEngineTime.syntax.clone(int(time.time())))
-__snmpEngineMaxMessageSize = MibScalarInstance(snmpEngineMaxMessageSize.name, (0,), snmpEngineMaxMessageSize.syntax.clone(4096))
+__snmpEngineMaxMessageSize = MibScalarInstance(snmpEngineMaxMessageSize.name, (0,),
+                                               snmpEngineMaxMessageSize.syntax.clone(4096))
 
 mibBuilder.exportSymbols(
     '__SNMP-FRAMEWORK-MIB',
-    snmpEngineID = __snmpEngineID,
-    snmpEngineBoots = __snmpEngineBoots,
-    snmpEngineTime = __snmpEngineTime,
-    snmpEngineMaxMessageSize = __snmpEngineMaxMessageSize
+    snmpEngineID=__snmpEngineID,
+    snmpEngineBoots=__snmpEngineBoots,
+    snmpEngineTime=__snmpEngineTime,
+    snmpEngineMaxMessageSize=__snmpEngineMaxMessageSize
 )
