@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
-# License: http://pysnmp.sf.net/license.html
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pysnmp/license.html
 #
 import sys
 from pysnmp.proto import rfc1902, rfc1905
@@ -16,7 +16,8 @@ from pysnmp import debug
 
 __all__ = ['ObjectIdentity', 'ObjectType', 'NotificationType']
 
-class ObjectIdentity:
+
+class ObjectIdentity(object):
     """Create an object representing MIB variable ID.
 
     At the protocol level, MIB variable is only identified by an OID.
@@ -50,7 +51,7 @@ class ObjectIdentity:
     Other parameters
     ----------------
     kwargs
-        MIB resolution options:
+        MIB resolution options(object):
 
         * whenever only MIB name is given, resolve into last variable defined
           in MIB if last=True.  Otherwise resolves to first variable (default).
@@ -256,7 +257,7 @@ class ObjectIdentity:
         Normally, ASN.1-to-Python MIB modules conversion is performed
         automatically through PySNMP/PySMI interaction. ASN1 MIB modules
         could also be manually compiled into Python via the
-        `mibdump.py <http://pysmi.sourceforge.net/user-perspective.html>`_
+        `mibdump.py <http://snmplabs.com/pysmi/mibdump.html>`_
         tool.
 
         Examples
@@ -355,7 +356,8 @@ class ObjectIdentity:
             addMibCompiler(mibViewController.mibBuilder,
                            ifAvailable=True, ifNotAdded=True)
         else:
-            debug.logger & debug.flagMIB and debug.logger('adding MIB compiler with source paths %s' % ', '.join(self.__asn1SourcesToAdd))
+            debug.logger & debug.flagMIB and debug.logger(
+                'adding MIB compiler with source paths %s' % ', '.join(self.__asn1SourcesToAdd))
             addMibCompiler(
                 mibViewController.mibBuilder,
                 sources=self.__asn1SourcesToAdd,
@@ -375,7 +377,8 @@ class ObjectIdentity:
         if self.__state & self.stClean:
             return self
 
-        MibScalar, MibTableColumn = mibViewController.mibBuilder.importSymbols('SNMPv2-SMI', 'MibScalar', 'MibTableColumn')
+        MibScalar, MibTableColumn = mibViewController.mibBuilder.importSymbols('SNMPv2-SMI', 'MibScalar',
+                                                                               'MibTableColumn')
 
         self.__indices = ()
 
@@ -418,7 +421,8 @@ class ObjectIdentity:
                     self.__oid
                 )
 
-            debug.logger & debug.flagMIB and debug.logger('resolved %r into prefix %r and suffix %r' % (self.__args, prefix, suffix))
+            debug.logger & debug.flagMIB and debug.logger(
+                'resolved %r into prefix %r and suffix %r' % (self.__args, prefix, suffix))
 
             modName, symName, _ = mibViewController.getNodeLocation(prefix)
 
@@ -435,7 +439,7 @@ class ObjectIdentity:
 
             debug.logger & debug.flagMIB and debug.logger('resolved prefix %r into MIB node %r' % (prefix, mibNode))
 
-            if isinstance(mibNode, MibTableColumn): # table column
+            if isinstance(mibNode, MibTableColumn):  # table column
                 if suffix:
                     rowModName, rowSymName, _ = mibViewController.getNodeLocation(
                         mibNode.name[:-1]
@@ -444,7 +448,7 @@ class ObjectIdentity:
                         rowModName, rowSymName
                     )
                     self.__indices = rowNode.getIndicesFromInstId(suffix)
-            elif isinstance(mibNode, MibScalar): # scalar
+            elif isinstance(mibNode, MibScalar):  # scalar
                 if suffix:
                     self.__indices = (rfc1902.ObjectName(suffix),)
             else:
@@ -486,9 +490,10 @@ class ObjectIdentity:
             )
             self.__label = label
 
-            debug.logger & debug.flagMIB and debug.logger('resolved %r into prefix %r and suffix %r' % (self.__args, prefix, suffix))
+            debug.logger & debug.flagMIB and debug.logger(
+                'resolved %r into prefix %r and suffix %r' % (self.__args, prefix, suffix))
 
-            if isinstance(mibNode, MibTableColumn): # table
+            if isinstance(mibNode, MibTableColumn):  # table
                 rowModName, rowSymName, _ = mibViewController.getNodeLocation(
                     mibNode.name[:-1]
                 )
@@ -501,8 +506,9 @@ class ObjectIdentity:
                         self.__oid += instIds
                         self.__indices = rowNode.getIndicesFromInstId(instIds)
                     except PyAsn1Error:
-                        raise SmiError('Instance index %r to OID convertion failure at object %r: %s' % (self.__args[2:], mibNode.getLabel(), sys.exc_info()[1]))
-            elif self.__args[2:]: # any other kind of MIB node with indices
+                        raise SmiError('Instance index %r to OID convertion failure at object %r: %s' % (
+                            self.__args[2:], mibNode.getLabel(), sys.exc_info()[1]))
+            elif self.__args[2:]:  # any other kind of MIB node with indices
                 if self.__args[2:]:
                     instId = rfc1902.ObjectName(
                         '.'.join([str(x) for x in self.__args[2:]])
@@ -522,9 +528,8 @@ class ObjectIdentity:
             s = rfc1902.OctetString()
             return '%s::%s%s%s' % (
                 self.__modName, self.__symName,
-                self.__indices and  '.' or '',
-                '.'.join([x.isSuperTypeOf(s) and '"%s"' % x.prettyPrint()
-                          or x.prettyPrint() for x in self.__indices])
+                self.__indices and '.' or '',
+                '.'.join([x.isSuperTypeOf(s, matchConstraints=False) and '"%s"' % x.prettyPrint() or x.prettyPrint() for x in self.__indices])
             )
         else:
             raise SmiError('%s object not fully initialized' % self.__class__.__name__)
@@ -628,12 +633,13 @@ class ObjectIdentity:
         else:
             raise SmiError('%s object not properly initialized for accessing %s' % (self.__class__.__name__, attr))
 
+
 # A two-element sequence of ObjectIdentity and SNMP data type object
-class ObjectType:
+class ObjectType(object):
     """Create an object representing MIB variable.
 
     Instances of :py:class:`~pysnmp.smi.rfc1902.ObjectType` class are
-    containters incorporating :py:class:`~pysnmp.smi.rfc1902.ObjectIdentity`
+    containers incorporating :py:class:`~pysnmp.smi.rfc1902.ObjectIdentity`
     class instance (identifying MIB variable) and optional value belonging
     to one of SNMP types (:RFC:`1902`).
 
@@ -682,12 +688,13 @@ class ObjectType:
     --------
     >>> from pysnmp.smi.rfc1902 import *
     >>> ObjectType(ObjectIdentity('1.3.6.1.2.1.1.1.0'))
-    ObjectType(ObjectIdentity('1.3.6.1.2.1.1.1.0'), Null())
+    ObjectType(ObjectIdentity('1.3.6.1.2.1.1.1.0'), Null(''))
     >>> ObjectType(ObjectIdentity('SNMPv2-MIB', 'sysDescr', 0), 'Linux i386')
     ObjectType(ObjectIdentity('SNMPv2-MIB', 'sysDescr', 0), 'Linux i386')
 
     """
     stDirty, stClean = 1, 2
+
     def __init__(self, objectIdentity, objectSyntax=rfc1905.unSpecified):
         if not isinstance(objectIdentity, ObjectIdentity):
             raise SmiError('initializer should be ObjectIdentity instance, not %r' % (objectIdentity,))
@@ -761,7 +768,7 @@ class ObjectType:
         Normally, ASN.1-to-Python MIB modules conversion is performed
         automatically through PySNMP/PySMI interaction. ASN1 MIB modules
         could also be manually compiled into Python via the
-        `mibdump.py <http://pysmi.sourceforge.net/user-perspective.html>`_
+        `mibdump.py <http://snmplabs.com/pysmi/mibdump.html>`_
         tool.
 
         Examples
@@ -837,7 +844,8 @@ class ObjectType:
 
         self.__args[0].resolveWithMib(mibViewController)
 
-        MibScalar, MibTableColumn = mibViewController.mibBuilder.importSymbols('SNMPv2-SMI', 'MibScalar', 'MibTableColumn')
+        MibScalar, MibTableColumn = mibViewController.mibBuilder.importSymbols('SNMPv2-SMI', 'MibScalar',
+                                                                               'MibTableColumn')
 
         if not isinstance(self.__args[0].getMibNode(),
                           (MibScalar, MibTableColumn)):
@@ -856,9 +864,11 @@ class ObjectType:
         try:
             self.__args[1] = self.__args[0].getMibNode().getSyntax().clone(self.__args[1])
         except PyAsn1Error:
-            raise SmiError('MIB object %r having type %r failed to cast value %r: %s' % (self.__args[0].prettyPrint(), self.__args[0].getMibNode().getSyntax().__class__.__name__, self.__args[1], sys.exc_info()[1]))
+            raise SmiError('MIB object %r having type %r failed to cast value %r: %s' % (
+                self.__args[0].prettyPrint(), self.__args[0].getMibNode().getSyntax().__class__.__name__, self.__args[1],
+                sys.exc_info()[1]))
 
-        if self.__args[1].isSuperTypeOf(rfc1902.ObjectIdentifier()):
+        if rfc1902.ObjectIdentifier().isSuperTypeOf(self.__args[1], matchConstraints=False):
             self.__args[1] = ObjectIdentity(self.__args[1]).resolveWithMib(mibViewController)
 
         self.__state |= self.stClean
@@ -874,11 +884,12 @@ class ObjectType:
         else:
             raise SmiError('%s object not fully initialized' % self.__class__.__name__)
 
-class NotificationType:
+
+class NotificationType(object):
     """Create an object representing SNMP Notification.
 
     Instances of :py:class:`~pysnmp.smi.rfc1902.NotificationType` class are
-    containters incorporating :py:class:`~pysnmp.smi.rfc1902.ObjectIdentity`
+    containers incorporating :py:class:`~pysnmp.smi.rfc1902.ObjectIdentity`
     class instance (identifying particular notification) and a collection
     of MIB variables IDs that
     :py:class:`~pysnmp.entity.rfc3413.oneliner.cmdgen.NotificationOriginator`
@@ -935,11 +946,12 @@ class NotificationType:
     >>> from pysnmp.smi.rfc1902 import *
     >>> NotificationType(ObjectIdentity('1.3.6.1.6.3.1.1.5.3'))
     NotificationType(ObjectIdentity('1.3.6.1.6.3.1.1.5.3'), (), {})
-    >>> NotificationType(ObjectIdentity('IP-MIB', 'linkDown'), ObjectName('3.5))
+    >>> NotificationType(ObjectIdentity('IP-MIB', 'linkDown'), ObjectName('3.5'))
     NotificationType(ObjectIdentity('1.3.6.1.6.3.1.1.5.3'), ObjectName('3.5'), {})
 
     """
     stDirty, stClean = 1, 2
+
     def __init__(self, objectIdentity, instanceIndex=(), objects={}):
         if not isinstance(objectIdentity, ObjectIdentity):
             raise SmiError('initializer should be ObjectIdentity instance, not %r' % (objectIdentity,))
@@ -989,7 +1001,7 @@ class NotificationType:
         """
         debug.logger & debug.flagMIB and debug.logger('additional var-binds: %r' % (varBinds,))
         if self.__state & self.stClean:
-            self.__varBinds.extend(varBinds)
+            raise SmiError('%s object is already sealed' % self.__class__.__name__)
         else:
             self.__additionalVarBinds.extend(varBinds)
         return self
@@ -1046,7 +1058,7 @@ class NotificationType:
         Normally, ASN.1-to-Python MIB modules conversion is performed
         automatically through PySNMP/PySMI interaction. ASN1 MIB modules
         could also be manually compiled into Python via the
-        `mibdump.py <http://pysmi.sourceforge.net/user-perspective.html>`_
+        `mibdump.py <http://snmplabs.com/pysmi/mibdump.html>`_
         tool.
 
         Examples
@@ -1138,18 +1150,32 @@ class NotificationType:
 
         mibNode = self.__objectIdentity.getMibNode()
 
+        varBindsLocation = {}
+
         if isinstance(mibNode, SmiNotificationType):
             for notificationObject in mibNode.getObjects():
-                objectIdentity = ObjectIdentity(*notificationObject+self.__instanceIndex).resolveWithMib(mibViewController)
+                objectIdentity = ObjectIdentity(*notificationObject + self.__instanceIndex).resolveWithMib(
+                    mibViewController)
                 self.__varBinds.append(
-                    ObjectType(objectIdentity, self.__objects.get(notificationObject, rfc1905.unSpecified)).resolveWithMib(mibViewController)
+                    ObjectType(objectIdentity,
+                               self.__objects.get(notificationObject, rfc1905.unSpecified)).resolveWithMib(
+                        mibViewController)
                 )
+                varBindsLocation[objectIdentity] = len(self.__varBinds) - 1
         else:
-            debug.logger & debug.flagMIB and debug.logger('WARNING: MIB object %r is not NOTIFICATION-TYPE (MIB not loaded?)' % (self.__objectIdentity,))
+            debug.logger & debug.flagMIB and debug.logger(
+                'WARNING: MIB object %r is not NOTIFICATION-TYPE (MIB not loaded?)' % (self.__objectIdentity,))
 
-        if self.__additionalVarBinds:
-            self.__varBinds.extend(self.__additionalVarBinds)
-            self.__additionalVarBinds = []
+        for varBinds in self.__additionalVarBinds:
+            if not isinstance(varBinds, ObjectType):
+                varBinds = ObjectType(ObjectIdentity(varBinds[0]), varBinds[1])
+            varBinds.resolveWithMib(mibViewController)
+            if varBinds[0] in varBindsLocation:
+                self.__varBinds[varBindsLocation[varBinds[0]]] = varBinds
+            else:
+                self.__varBinds.append(varBinds)
+
+        self.__additionalVarBinds = []
 
         self.__state |= self.stClean
 
